@@ -25,17 +25,14 @@
 #ifndef __PYFONT_HPP
 #define __PYFONT_HPP
 
-#include <SFML/Graphics/Font.hpp>
-#include <iostream>
-
 #include <Python.h>
-#include <structmember.h>
 
-#include "offsetof.hpp"
+#include <SFML/Graphics/Font.hpp>
 
 
 typedef struct {
 	PyObject_HEAD
+	bool Owner;
 	sf::Font *obj;
 } PySfFont;
 
