@@ -25,13 +25,9 @@
 #ifndef __PYLISTENER_HPP
 #define __PYLISTENER_HPP
 
-#include <SFML/Audio/Listener.hpp>
-#include <iostream>
-
 #include <Python.h>
-#include <structmember.h>
 
-#include "offsetof.hpp"
+#include <SFML/Audio/Listener.hpp>
 
 
 typedef struct {
