@@ -25,17 +25,13 @@
 #ifndef __PYPOSTFX_HPP
 #define __PYPOSTFX_HPP
 
-#include <SFML/Graphics/PostFX.hpp>
-#include <iostream>
-
 #include <Python.h>
-#include <structmember.h>
 
-#include "Drawable.hpp"
-#include "Image.hpp"
+#include <SFML/Graphics/PostFX.hpp>
 
 typedef struct {
 	PyObject_HEAD
+	bool IsCustom;
 	sf::PostFX *obj;
 } PySfPostFX;
 
