@@ -25,17 +25,16 @@
 #ifndef __PYRENDERWINDOW_HPP
 #define __PYRENDERWINDOW_HPP
 
-#include <SFML/Graphics.hpp>
-#include <iostream>
-
 #include <Python.h>
-#include <structmember.h>
 
-#include "WindowSettings.hpp"
+#include <SFML/Graphics.hpp>
+
+#include "View.hpp"
 
 typedef struct {
 	PyObject_HEAD
 	sf::RenderWindow *obj;
+	PySfView *View;
 } PySfRenderWindow;
 
 
