@@ -25,17 +25,14 @@
 #ifndef __PYSHAPE_HPP
 #define __PYSHAPE_HPP
 
-#include <SFML/Graphics/Shape.hpp>
-#include <iostream>
-
 #include <Python.h>
-#include <structmember.h>
 
-#include "offsetof.hpp"
+#include <SFML/Graphics/Shape.hpp>
 
 
 typedef struct {
 	PyObject_HEAD
+	bool IsCustom;
 	sf::Shape *obj;
 } PySfShape;
 
