@@ -25,11 +25,9 @@
 #ifndef __PYSLEEP_HPP
 #define __PYSLEEP_HPP
 
-#include <SFML/System/Sleep.hpp>
-#include <iostream>
-
 #include <Python.h>
-#include <structmember.h>
+
+#include <SFML/System/Sleep.hpp>
 
 PyObject *
 PySFML_Sleep (PyObject *self, PyObject *args);
