@@ -25,21 +25,19 @@
 #ifndef __PYSPRITE_HPP
 #define __PYSPRITE_HPP
 
-#include <SFML/Graphics/Sprite.hpp>
-#include <SFML/Graphics/Image.hpp>
-#include <iostream>
-
 #include <Python.h>
-#include <structmember.h>
 
-#include "Drawable.hpp"
+#include <SFML/Graphics/Sprite.hpp>
+
 #include "Image.hpp"
 #include "Rect.hpp"
 
 typedef struct {
 	PyObject_HEAD
+	bool IsCustom;
 	sf::Sprite *obj;
 	PySfImage *Image;
+	PySfIntRect *SubRect;
 } PySfSprite;
 
 #endif
