@@ -25,15 +25,17 @@
 #ifndef __PYSTRING_HPP
 #define __PYSTRING_HPP
 
-#include <SFML/Graphics/String.hpp>
-#include <iostream>
-
 #include <Python.h>
-#include <structmember.h>
+
+#include <SFML/Graphics/String.hpp>
+
+#include "Font.hpp"
 
 typedef struct {
 	PyObject_HEAD
+	bool IsCustom;
 	sf::String *obj;
+	PySfFont *font;
 } PySfString;
 
 void PySfString_InitConst();
