@@ -25,16 +25,12 @@
 #ifndef __PYVIEW_HPP
 #define __PYVIEW_HPP
 
+#include <Python.h>
+
 #include <SFML/Graphics/View.hpp>
-#include <iostream>
 
 #include "Rect.hpp"
 
-#include <Python.h>
-#include <structmember.h>
-
-#include "offsetof.hpp"
-
 typedef struct {
 	PyObject_HEAD
 	bool Owner;
