@@ -25,17 +25,9 @@
 #ifndef __PYWINDOW_HPP
 #define __PYWINDOW_HPP
 
-#include <SFML/System.hpp>
-#include <SFML/Window.hpp>
-#include <iostream>
-
 #include <Python.h>
-#include <structmember.h>
 
-#include "Event.hpp"
-#include "VideoMode.hpp"
-#include "Input.hpp"
-#include "WindowSettings.hpp"
+#include <SFML/Window/Window.hpp>
 
 
 typedef struct {
